@@ -30,6 +30,9 @@ def check_isoformat_none_case(v: Optional[str]):
 class HttpMethodType(Enum):
     HTTP_METHOD_GET = 'GET'
     HTTP_METHOD_POST = 'POST'
+    HTTP_METHOD_PUT = 'PUT'
+    HTTP_METHOD_PATCH = 'PATCH'
+    HTTP_METHOD_DELETE = 'DELETE'
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
