@@ -164,8 +164,8 @@ def get_payment_event_data(**kwargs):
                 },
             ],
             'update': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'GET'},
-            'confirm': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'POST'},
-            'cancel': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'POST'},
+            'confirm': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
+            'cancel': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
         },
         'payer': {
             'type': 'human',
@@ -285,8 +285,8 @@ def get_links_data(**kwargs):
             },
         ],
         'update': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'GET'},
-        'confirm': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'POST'},
-        'cancel': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'POST'},
+        'confirm': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
+        'cancel': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
         **kwargs,
     }
 
